==> ejc-assistrmat-impl-3.0.0-20220908.024512-172-sources.jar: com/ejianc/business/outrmat/stop/bean/OutRmatStopDetailEntity.java <==
package com.ejianc.business.outrmat.stop.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 停用单材料明细实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_stop_detail")
public class OutRmatStopDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="stop_id")
    private Long stopId; // 停用单主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类主键
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="spec")
    private String spec; // 规格/型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位主键
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="enable_num")
    private BigDecimal enableNum; // 可停用数量
    @TableField(value="stop_time")
    private Date stopTime; // 停用时间
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private String sourceId; // 来源主键


    @TableField(value="unit_m_id")
    private Long unitMId; // 计量单位主键
    @TableField(value="unit_m_name")
    private String unitMName; // 计量单位
    @TableField(value="num_m")
    private BigDecimal numM; // 计量数量
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数

    public Long getStopId() {
        return stopId;
    }

    public void setStopId(Long stopId) {
        this.stopId = stopId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getEnableNum() {
        return enableNum;
    }

    public void setEnableNum(BigDecimal enableNum) {
        this.enableNum = enableNum;
    }
    public Date getStopTime() {
        return stopTime;
    }

    public void setStopTime(Date stopTime) {
        this.stopTime = stopTime;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
}

==> ejc-assistrmat-impl-3.0.0-20230419.084517-349-sources.jar: com/ejianc/business/outrmat/stop/bean/OutRmatStopDetailEntity.java <==
package com.ejianc.business.outrmat.stop.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 停用单材料明细实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outrmat_stop_detail")
public class OutRmatStopDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="stop_id")
    private Long stopId; // 停用单主键
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类主键
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_id")
    private Long materialId; // 物料主键
    @TableField(value="material_code")
    private String materialCode; // 物料编码
    @TableField(value="material_name")
    private String materialName; // 物料名称
    @TableField(value="spec")
    private String spec; // 规格/型号
    @TableField(value="unit_id")
    private Long unitId; // 计量单位主键
    @TableField(value="unit_name")
    private String unitName; // 计量单位
    @TableField(value="num")
    private BigDecimal num; // 数量
    @TableField(value="enable_num")
    private BigDecimal enableNum; // 可停用数量
    @TableField(value="stop_time")
    private Date stopTime; // 停用时间
    @TableField(value="rent_calculation_type")
    private String rentCalculationType; // 计租方式：0-日租，1-月租，2-工程量租
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="source_id")
    private String sourceId; // 来源主键


    @TableField(value="unit_m_id")
    private Long unitMId; // 计量单位主键
    @TableField(value="unit_m_name")
    private String unitMName; // 计量单位
    @TableField(value="num_m")
    private BigDecimal numM; // 计量数量
    @TableField(value="trans_scale")
    private BigDecimal transScale; // 转换系数
    @TableField(value="store_id")
    private Long storeId; // 仓库主键
    @TableField(value="store_name")
    private String storeName; // 仓库名称
    @TableField(value="source_type")
    private Integer sourceType; // 材料来源,0-自购,1-租赁

    public Long getStoreId() {
        return storeId;
    }

    public void setStoreId(Long storeId) {
        this.storeId = storeId;
    }

    public String getStoreName() {
        return storeName;
    }

    public void setStoreName(String storeName) {
        this.storeName = storeName;
    }

    public Integer getSourceType() {
        return sourceType;
    }

    public void setSourceType(Integer sourceType) {
        this.sourceType = sourceType;
    }

    public Long getStopId() {
        return stopId;
    }

    public void setStopId(Long stopId) {
        this.stopId = stopId;
    }
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getMaterialCode() {
        return materialCode;
    }

    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getNum() {
        return num;
    }

    public void setNum(BigDecimal num) {
        this.num = num;
    }
    public BigDecimal getEnableNum() {
        return enableNum;
    }

    public void setEnableNum(BigDecimal enableNum) {
        this.enableNum = enableNum;
    }
    public Date getStopTime() {
        return stopTime;
    }

    public void setStopTime(Date stopTime) {
        this.stopTime = stopTime;
    }
    public String getRentCalculationType() {
        return rentCalculationType;
    }

    public void setRentCalculationType(String rentCalculationType) {
        this.rentCalculationType = rentCalculationType;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public String getSourceId() {
        return sourceId;
    }

    public void setSourceId(String sourceId) {
        this.sourceId = sourceId;
    }

    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }

    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }

    public BigDecimal getNumM() {
        return numM;
    }

    public void setNumM(BigDecimal numM) {
        this.numM = numM;
    }

    public BigDecimal getTransScale() {
        return transScale;
    }

    public void setTransScale(BigDecimal transScale) {
        this.transScale = transScale;
    }
}
